@@ -13,7 +13,7 @@ except ImportError:  # pragma: nocover
     from urllib import urlencode
 from . import exceptions, utils
 
-__version__ = "0.8.1"
+__version__ = "0.8.3"
 
 _log = logging.getLogger(__name__)
 
@@ -34,7 +34,13 @@ class Client(utils._SetEnv):
         hdr = {"Authorization": "Bearer {}".format(self._session.access_token)}
         _log.debug("{}".format(path))
         if data is not None:
-            _log.debug("data: {}".format(json.dumps(data, cls=utils.JSONWithDecimalEncoder, indent=2, sort_keys=True)))
+            _log.debug(
+                "data: {}".format(
+                    json.dumps(
+                        data, cls=utils.JSONWithDecimalEncoder, indent=2, sort_keys=True
+                    )
+                )
+            )
         rsp = func(url, headers=hdr, data=json.dumps(data) if data else None)
         if rsp.status_code == 204:
             result = None
@@ -46,6 +52,10 @@ class Client(utils._SetEnv):
             if rsp.status_code == 400:
                 if "o pocket found" in message:
                     raise exceptions.NoPocketFound(message)
+                if "BIC and IBAN does not match" in message:
+                    raise exceptions.BICIBANMismatch(message)
+                if "ould not interpret numbers after plus-sign" in message:
+                    raise exceptions.InvalidPhoneNumber(message)
             if rsp.status_code == 401:
                 raise exceptions.Unauthorized(rsp.status_code, message)
             if rsp.status_code == 422:
